aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/fileset_url.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/fileset_url.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/fileset_url.py15
1 files changed, 8 insertions, 7 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/fileset_url.py b/python_openapi_client/fatcat_openapi_client/models/fileset_url.py
index f7efab60..cde1119c 100644
--- a/python_openapi_client/fatcat_openapi_client/models/fileset_url.py
+++ b/python_openapi_client/fatcat_openapi_client/models/fileset_url.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -18,19 +18,20 @@ import six
class FilesetUrl(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'url': 'str',
'rel': 'str'
}
@@ -41,7 +42,7 @@ class FilesetUrl(object):
}
def __init__(self, url=None, rel=None): # noqa: E501
- """FilesetUrl - a model defined in Swagger""" # noqa: E501
+ """FilesetUrl - a model defined in OpenAPI""" # noqa: E501
self._url = None
self._rel = None
@@ -102,7 +103,7 @@ class FilesetUrl(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -18,19 +18,20 @@ import six
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name